function L = bandWheel(d1, d2, d)
%bandWheel: calculation of band-wheel length
%
% Syntax:
%   [L] = band_wheel(d1,d2,d);
% Example:
%   L = band_wheel(4,8,12)
% Input:
%   d1 ... diameter of 1st wheel
%   d2 ... diameter of 2nd wheel
%   d ... distance between wheels
% Output:
%   L ... length of band-wheel
%
% ver. 2, 03-2013, miloslav.capek@fel.cvut.cz

r1 = d1/2;
r2 = d2/2;

l2 = sqrt(d^2-(r2-r1)^2);

phi = asin((r2-r1)/d);
l1 = (pi-2*phi)*r1;
l3 = (pi+2*phi)*r2;

L = l1 + 2*l2 + l3;
end

